@@ -3,6 +3,9 @@ import os
 
 from cookiecutter.main import cookiecutter
 
+from service_buddy_too.service.service import Service
+from service_buddy_too.util import command_util
+
 
 def _make_cookie_safe(service_definition):
     ret = {}
@@ -12,13 +15,12 @@ def _make_cookie_safe(service_definition):
 
 
 class CookeCutterProjectCreator(object):
-    def __init__(self, template_dir, dry_run, templates):
+    def __init__(self, template_dir, templates):
         super(CookeCutterProjectCreator, self).__init__()
         self.template_dir = template_dir
         self.templates =templates
-        self.dry_run = dry_run
 
-    def create_project(self, service_definition, app_dir, extra_config=None):
+    def create_project(self, service_definition:Service,destination_directory:str, extra_config=None):
         template = self._lookup_service_template(service_definition.get_service_type())
         if template['type'] == 'file':
             location = os.path.abspath(os.path.join(self.template_dir, template['location']))
@@ -31,10 +33,14 @@ class CookeCutterProjectCreator(object):
         extra_context.update(_make_cookie_safe(template))
         # allow user to specify the directory in the github repo
         directory= template.get('directory', None)
-        if self.dry_run:
+        if command_util.dry_run_global:
             logging.error("Creating project from template {} ".format(location))
         else:
-            return cookiecutter(location, no_input=True, extra_context=extra_context, output_dir=app_dir,directory=directory)
+            return cookiecutter(location,
+                                no_input=True,
+                                extra_context=extra_context,
+                                output_dir=destination_directory,
+                                directory=directory)
 
     def _lookup_service_template(self, service_type):
         if service_type not in self.templates:
