@@ -24,7 +24,7 @@ def invoke_process(args, exec_dir=None):
             returncode = e.returncode
 
         for line in output.splitlines():
-            logging.info(u'[exec] %s', line)
+            logging.debug(u'[exec] %s', line)
         logging.debug(u'[exec] invoke_process complete args=%r, exec_dir=%r, dry_run=%r', args, exec_dir, dry_run_global)
 
         return returncode
